==> knative-model-6.8.0-sources.jar: io/fabric8/knative/internal/eventing/pkg/apis/duck/v1alpha1/PlacementFluent.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PlacementFluent<A extends PlacementFluent<A>> extends BaseFluent<A>{
  public PlacementFluent() {
  }
  public PlacementFluent(Placement instance) {
    instance = (instance != null ? instance : new Placement());

    if (instance != null) {
      this.withPodName(instance.getPodName());
      this.withVreplicas(instance.getVreplicas());
      this.withPodName(instance.getPodName());
      this.withVreplicas(instance.getVreplicas());
    }
  }
  private String podName;
  private Integer vreplicas;
  public String getPodName() {
    return this.podName;
  }
  public A withPodName(String podName) {
    this.podName=podName; return (A) this;
  }
  public boolean hasPodName() {
    return this.podName != null;
  }
  public Integer getVreplicas() {
    return this.vreplicas;
  }
  public A withVreplicas(Integer vreplicas) {
    this.vreplicas=vreplicas; return (A) this;
  }
  public boolean hasVreplicas() {
    return this.vreplicas != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementFluent that = (PlacementFluent) o;
    if (!java.util.Objects.equals(podName, that.podName)) return false;

    if (!java.util.Objects.equals(vreplicas, that.vreplicas)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(podName,  vreplicas,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (podName != null) { sb.append("podName:"); sb.append(podName + ","); }
    if (vreplicas != null) { sb.append("vreplicas:"); sb.append(vreplicas); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/eventing/pkg/apis/duck/v1alpha1/PlacementFluent.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PlacementFluent<A extends PlacementFluent<A>> extends BaseFluent<A>{
  public PlacementFluent() {
  }
  
  public PlacementFluent(Placement instance) {
    this.copyInstance(instance);
  }
  private String podName;
  private Integer vreplicas;
  
  protected void copyInstance(Placement instance) {
    instance = (instance != null ? instance : new Placement());
  
    if (instance != null) {
        this.withPodName(instance.getPodName());
        this.withVreplicas(instance.getVreplicas());
        this.withPodName(instance.getPodName());
        this.withVreplicas(instance.getVreplicas());
      }
  }
  
  public String getPodName() {
    return this.podName;
  }
  
  public A withPodName(String podName) {
    this.podName=podName; return (A) this;
  }
  
  public boolean hasPodName() {
    return this.podName != null;
  }
  
  public Integer getVreplicas() {
    return this.vreplicas;
  }
  
  public A withVreplicas(Integer vreplicas) {
    this.vreplicas=vreplicas; return (A) this;
  }
  
  public boolean hasVreplicas() {
    return this.vreplicas != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementFluent that = (PlacementFluent) o;
    if (!java.util.Objects.equals(podName, that.podName)) return false;
  
    if (!java.util.Objects.equals(vreplicas, that.vreplicas)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(podName,  vreplicas,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (podName != null) { sb.append("podName:"); sb.append(podName + ","); }
    if (vreplicas != null) { sb.append("vreplicas:"); sb.append(vreplicas); }
    sb.append("}");
    return sb.toString();
  }
  

}
